@@ -1658,11 +1658,17 @@ void on_open_current_folder_as_root ( GtkMenuItem *menuitem,
     PtkFileBrowser* file_browser;
     const char* cwd;
     char* argv[ 4 ];
-    char* su = g_find_program_in_path( "gksudo" );
+    char* su;
+#ifdef PREFERABLE_SUDO_PROG
+    su = g_find_program_in_path( PREFERABLE_SUDO_PROG );
+#else
+    /* Use default search rules */
+    su = g_find_program_in_path( "gksudo" );
     if ( ! su )
         su = g_find_program_in_path( "gksu" );
     if ( ! su )
         su = g_find_program_in_path( "kdesu" );
+#endif
     if ( ! su )
     {
         ptk_show_error( GTK_WINDOW( main_window ), _("Error"), _( "gksu or kdesu is not found" ) );
@@ -1718,6 +1724,12 @@ void on_bookmark_item_activate ( GtkMenuItem* menu, gpointer user_data )
 void on_bookmarks_change( PtkBookmarks* bookmarks, FMMainWindow* main_window )
 {
     GtkWidget * bookmarks_menu = create_bookmarks_menu( main_window );
+    /* FIXME: We have to popupdown the menu first, if it's showed on screen.
+      * Otherwise, it's rare but possible that we try to replace the menu while it's in use.
+      *  In that way, gtk+ will hang.  So some dirty hack is used here.
+      *  We popup down the old menu, if it's currently shown.
+      */
+    gtk_menu_popdown( (GtkMenu*)gtk_menu_item_get_submenu ( GTK_MENU_ITEM ( main_window->bookmarks ) ) );
     gtk_menu_item_set_submenu ( GTK_MENU_ITEM ( main_window->bookmarks ),
                                 bookmarks_menu );
 }
